@@ -58,7 +58,7 @@ class ArticleCommentItem(scrapy.Item):
     created_date = scrapy.Field()
 
 
-class PaperCommentItem(scrapy.Item):
+class PaperItem(scrapy.Item):
     task_id = scrapy.Field()
     domain_url = scrapy.Field()
     domain_id = scrapy.Field()
@@ -75,10 +75,10 @@ class PaperCommentItem(scrapy.Item):
     url_md5 = scrapy.Field()
     author = scrapy.Field()
     content = scrapy.Field()
+    article_html = scrapy.Field()
     lang = scrapy.Field()  # 正文语言
-    abstract = scrapy.Field()  # 摘要
-    description_cn = scrapy.Field()
-    description_en = scrapy.Field()
+    abstract_cn = scrapy.Field()  # 摘要
+    abstract_en = scrapy.Field()
     keywords = scrapy.Field()  # 关键词
     doi = scrapy.Field()  # DOI
     year = scrapy.Field()  # 年份
@@ -137,8 +137,8 @@ def get_comment_item(response, post_result, block, uploadOss=True):
     return item
 
 
-def get_papaer_item(response, source, block, parse=True, uploadOss=True):
-    item = PaperCommentItem()
+def get_paper_item(response, source, block, parse=True, uploadOss=True):
+    item = PaperItem()
     item["domain_url"] = block["domain_url"]
     item["domain_id"] = block["domain_id"]
     item["domain_name"] = block["domain_name"]
